@@ -51,8 +51,7 @@ int Timer::length() const
 
 QString Timer::lengthPretty() const
 {
-    qint64 len = m_length, hours = len / 60 / 60, minutes = len / 60 - hours * 60, seconds = len - hours * 60 * 60 - minutes * 60;
-    return QStringLiteral("%1:%2:%3").arg(hours).arg(minutes, 2, 10, QLatin1Char('0')).arg(seconds, 2, 10, QLatin1Char('0'));
+    return toPretty(m_length);
 }
 
 void Timer::setLength(int length)
@@ -67,7 +66,17 @@ int Timer::elapsed() const
 
 QString Timer::elapsedPretty() const
 {
-    qint64 len = m_elapsed, hours = len / 60 / 60, minutes = len / 60 - hours * 60, seconds = len - hours * 60 * 60 - minutes * 60;
+    return toPretty(m_elapsed);
+}
+
+QString Timer::remainingPretty() const
+{
+    return toPretty(m_length - m_elapsed);
+}
+
+QString Timer::toPretty(int len) const
+{
+    qint64 hours = len / 60 / 60, minutes = len / 60 - hours * 60, seconds = len - hours * 60 * 60 - minutes * 60;
     return QStringLiteral("%1:%2:%3").arg(hours).arg(minutes, 2, 10, QLatin1Char('0')).arg(seconds, 2, 10, QLatin1Char('0'));
 }
 
